@@ -1,4 +1,5 @@
-from csp.impl.channels import Box
+from csp.impl.channels import Box, ManyToManyChannel as Channel
+from csp import go, put, take, close
 
 def map_from(f, ch):
     class Channel:
@@ -55,3 +56,16 @@ def map_from(f, ch):
 #     out.take = take
 
 #     return out
+
+def filter_from(predicate, channel, buf):
+    out = Channel(buf)
+    def _filter():
+        while True:
+            value = yield take(channel)
+            if value is None:
+                close(out)
+                break
+            if predicate(value):
+                yield put(out, value)
+    go(_filter())
+    return out
