@@ -11,8 +11,8 @@ def fan_in(input1, input2):
     def collect(i):
         while True:
             yield put(c, (yield take(i)))
-    go(collect(input1))
-    go(collect(input2))
+    go(collect, input1)
+    go(collect, input2)
     return c
 
 
