@@ -15,11 +15,11 @@ def main():
     left = leftmost
     for i in range(n):
         right = Channel()
-        go(f(left, right))
+        go(f, left, right)
         left = right
 
     def start(c):
         yield put(c, 1)
 
-    go(start(right))
+    go(start, right)
     print (yield take(leftmost))
