@@ -1,18 +1,18 @@
-from csp import go, wait, take, stop
+from csp import go_chan, sleep, take, stop
 
 
 def lazy_echo(x):
-    yield wait(0.1)
+    yield sleep(0.1)
     print "I'm done"
     yield stop(x)
 
 
 def main():
-    chan = go(lazy_echo(1), True)
+    chan = go_chan(lazy_echo, 1)
     print (yield take(chan))
 
-    chan = go(lazy_echo(2), True)
-    yield wait(1)
+    chan = go_chan(lazy_echo, 2)
+    yield sleep(1)
     print (yield take(chan))
 
     yield stop("Done")
