@@ -1,8 +1,8 @@
-from csp import Channel, put, take, go, alts, wait
+from csp import Channel, put, go, alts, sleep, CLOSED
 
 
 def produce(chan, value):
-    yield wait(0.1)
+    yield sleep(0.1)
     yield put(chan, value)
 
 
@@ -10,22 +10,22 @@ def main():
     chans = []
     for i in range(20):
         chan = Channel()
-        go(produce(chan, i))
+        go(produce, chan, i)
         chans.append(chan)
 
     def timeout(seconds):
         chan = Channel()
         def t():
-            yield wait(seconds)
+            yield sleep(seconds)
             chan.close()
-        go(t())
+        go(t)
         return chan
 
     chans.append(timeout(0.3))
 
     while True:
         value, chan = yield alts(chans)
-        if value is None:
+        if value == CLOSED:
             print "time out"
             break
         else:
